@@ -27,18 +27,14 @@ def download_images_from_remote(cache_dir: str, prefix: str, tasks: Dict):
     os.makedirs(os.path.join(cache_dir, prefix), exist_ok=True)
     for task in tqdm.tqdm(tasks):
         # Download, if not already do
-        local_path = os.path.join(
-            cache_dir, prefix, str(task["taskId"]) + ".png"
-        )
+        local_path = os.path.join(cache_dir, prefix, str(task["taskId"]) + ".png")
         if os.path.exists(local_path):
             continue
 
         try:
             image = imageio.imread(task["itemsPresigned"][0])
-        except Exception:
-            redbrick_sagemaker.logger.warning(
-                "Failed to download %s", task["items"]
-            )
+        except (ValueError, OSError):
+            redbrick_sagemaker.logger.warning("Failed to download %s", task["items"])
 
         # Write to disk
         try:
@@ -46,7 +42,5 @@ def download_images_from_remote(cache_dir: str, prefix: str, tasks: Dict):
                 os.path.join(local_path),
                 image,
             )
-        except Exception:
-            redbrick_sagemaker.logger.warning(
-                "Failed to download %s", task["items"][0]
-            )
+        except (ValueError, OSError):
+            redbrick_sagemaker.logger.warning("Failed to download %s", task["items"][0])
