@@ -1,11 +1,5 @@
 """RedBrick related helper functions."""
 
-import os
-import imageio
-from typing import Dict
-
-import redbrick_sagemaker
-
 
 def create_taxonomy_map(taxonomy):
     """
